==> glademm_0.6.4.orig.tar.gz: glademm-0.6.4/src/writers/gnome_messagebox.cc <==
// $Id: gnome_messagebox.cc,v 1.6 2001/10/11 14:07:24 christof Exp $
/*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
 *  Copyright (C) 1998  Christof Petig
 *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "gnome_dialog.hh"

class Gnome_MessageBox : public Gnome_Dialog
{public:
	typedef Gnome_Dialog Parent;
	virtual const std::string TypeName(const Widget &w) const;
	virtual const std::string IncludeName(const Widget &w) const;
	Gnome_MessageBox();
//	virtual void Configure(const Widget &w, CxxFile &f,const std::string &instance) const;
	virtual void ConstructionArgs(const Widget &w, CxxFile &f) const 
	{ f.FunctionArg(); }
	virtual bool NeedExplicitCtor(const Widget &w) const
	{ return false; }
};

static Gnome_MessageBox Gnome_MessageBox;

const std::string Gnome_MessageBox::TypeName(const Widget &w) const
{  return GnomePrefix()+"MessageBox";
}

const std::string Gnome_MessageBox::IncludeName(const Widget &w) const
{  return "gnome--/messagebox.h";
}

Gnome_MessageBox::Gnome_MessageBox()
{  Writer["GnomeMessageBox"]=this;
}

==> glademm_2.0.0.1.orig.tar.gz: glademm-2.0.0.1/src/writers/gnome_messagebox.cc <==
// $Id: gnome_messagebox.cc,v 1.7 2002/11/04 11:31:03 christof Exp $
/*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
 *  Copyright (C) 1998  Christof Petig
 *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "gnome_dialog.hh"

class Gnome_MessageBox : public Gnome_Dialog
{public:
	typedef Gnome_Dialog Parent;
	virtual const std::string TypeName(const Widget &w) const;
	virtual const std::string IncludeName(const Widget &w) const;
	Gnome_MessageBox();
//	virtual void Configure(const Widget &w, CxxFile &f,const std::string &instance) const;
	virtual void ConstructionArgs(const Widget &w, CxxFile &f) const 
	{ f.FunctionArg(); }
	virtual bool NeedExplicitCtor(const Widget &w) const
	{ return false; }
};

static Gnome_MessageBox Gnome_MessageBox;

const std::string Gnome_MessageBox::TypeName(const Widget &w) const
{  return GnomeUIPrefix()+"MessageBox";
}

const std::string Gnome_MessageBox::IncludeName(const Widget &w) const
{  return Configuration.GnomeUImmIncludePath()+"messagebox.h";
}

Gnome_MessageBox::Gnome_MessageBox()
{  Writer["GnomeMessageBox"]=this;
}
